# Changelog

All notable changes to the Django Hierarchical Models package will be documented in this file.

## [0.1.0] - 2024-03-24

### Added
- Initial version of the package with hierarchical model inheritance
- Support for regular fields and ManyToMany fields
- Admin integration with `HierarchicalModelAdmin`
- Initial documentation 